"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DownloadNode = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const wa_decrypt_1 = require("@open-wa/wa-decrypt");
const mime_types_1 = __importDefault(require("mime-types"));
class DownloadNode {
    constructor() {
        this.description = {
            displayName: 'Evolution Media Downloader',
            name: 'downloadNode',
            icon: 'file:logo.svg',
            group: ['transform'],
            version: 1,
            description: 'Utility node to download media from Evolution API messages',
            defaults: {
                name: 'Evolution Media Downloader',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'Evolution Message Data',
                    name: 'data',
                    type: 'json',
                    default: '{{ $json.body.data }}',
                    placeholder: '',
                    description: 'The node data from Evolution API message',
                }
            ],
        };
    }
    static async fetchMedia(fnc, data) {
        if (data === null) {
            return null;
        }
        const { messageType } = data;
        if (!['audioMessage', 'imageMessage'].includes(messageType)) {
            return null;
        }
        const { url, mimetype, fileSha256, fileLength, mediaKey } = data['message'][messageType];
        try {
            const ext = mime_types_1.default.extension(mimetype);
            const type = mimetype.substring(0, mimetype.indexOf('/'));
            const buffer = await (0, wa_decrypt_1.decryptMedia)({
                deprecatedMms3Url: url,
                mimetype,
                filehash: fileSha256,
                mediaKey,
                type,
                size: fileLength
            });
            return {
                key: {
                    data: buffer.toString('base64'),
                    mimeType: mimetype,
                    fileSize: fileLength,
                    fileName: `file.${ext}`,
                    fileExtension: ext,
                    fileType: type
                }
            };
        }
        catch (err) {
            throw new n8n_workflow_1.NodeOperationError(fnc.getNode(), 'Could not decrypt media message');
        }
    }
    async execute() {
        const items = this.getInputData();
        let item;
        let data;
        let binary;
        for (let itemIndex = 0; itemIndex < items.length; itemIndex++) {
            try {
                data = this.getNodeParameter('data', itemIndex);
                binary = await DownloadNode.fetchMedia(this, data);
                if (binary) {
                    item = items[itemIndex];
                    item.binary = binary;
                }
            }
            catch (error) {
                if (this.continueOnFail()) {
                    items.push({ json: this.getInputData(itemIndex)[0].json, error, pairedItem: itemIndex });
                }
                else {
                    if (error.context) {
                        error.context.itemIndex = itemIndex;
                        throw error;
                    }
                    throw new n8n_workflow_1.NodeOperationError(this.getNode(), error, {
                        itemIndex,
                    });
                }
            }
        }
        return this.prepareOutputData(items);
    }
}
exports.DownloadNode = DownloadNode;
//# sourceMappingURL=DownloadNode.node.js.map